@@ -19,7 +19,7 @@ TS_V1_FMT = ("%Y/%Y_%m/%Y_%m_%d/%Y_%m_%d_%H/"
 TS_V2_FMT = ("%Y/%Y_%m/%Y_%m_%d/%Y_%m_%d_%H/"
              "{tsname:s}_%Y_%m_%d_%H_%M_%S_{n:02d}.{ext:s}")
 TS_FMT = TS_V1_FMT
-TS_NAME_FMT = "{expt:s}-{loc:s}-{cam:s}~{res:s}-{step:s}"
+TS_NAME_FMT = "{expt:s}-{loc:s}~{res:s}-{step:s}"
 FULLRES_CONSTANTS = {"original", "orig", "fullres"}
 IMAGE_TYPE_CONSTANTS = {"raw", "jpg"}
 RAW_FORMATS = {"cr2", "nef", "tif", "tiff"}
@@ -48,7 +48,6 @@ LOG = logging.getLogger("exif2timestream")
 # compability.
 FIELDS = {
     'use': 'USE',
-    'name': 'CAMERA_NAME',
     'location': 'LOCATION',
     'expt': 'CURRENT_EXPT',
     'source': 'SOURCE',
@@ -69,7 +68,6 @@ FIELDS = {
 
 FIELD_ORDER = [
     'use',
-    'name',
     'location',
     'expt',
     'source',
@@ -197,7 +195,6 @@ def validate_camera(camera):
         Required(FIELDS["archive_dest"]): path_exists,
         Required(FIELDS["method"], default="archive"): \
             InList(["copy", "archive", "move"]),
-        Required(FIELDS["name"]): str,
         Required(FIELDS["source"]): path_exists,
         FIELDS["mode"]: InList(["batch", "watch"]),
         FIELDS["resolutions"]: resolution_str,
@@ -283,7 +280,6 @@ def make_timestream_name(camera, res="fullres", step="orig"):
     return TS_NAME_FMT.format(
         expt=camera[FIELDS["expt"]],
         loc=camera[FIELDS["location"]],
-        cam=camera[FIELDS["name"]],
         res=res,
         step=step
     )
@@ -482,10 +478,8 @@ def find_image_files(camera):
                     except KeyError:
                         ext_files[ext] = []
                         ext_files[ext].append(fle_path)
-            LOG.info("Found {0} {1} files for camera {2}.".format(
-                len(files),
-                ext,
-                camera[FIELDS["name"]]))
+            LOG.info("Found {0} {1} files for camera.".format(
+                    len(files), ext))
     return ext_files
 
 
@@ -535,8 +529,8 @@ def main(opts):
     cameras = parse_camera_config_csv(opts["-c"])
     n_images = 0
     for camera in cameras:
-        print("Processing camera {0}".format(camera[FIELDS["name"]]))
-        LOG.info("Processing camera {0}".format(camera[FIELDS["name"]]))
+        print("Processing camera {0}".format(camera[FIELDS["expt"]]))
+        LOG.info("Processing camera {0}".format(camera[FIELDS["expt"]]))
         for ext, images in find_image_files(camera).iteritems():
             images = sorted(images)
             n_cam_images = len(images)
